# authentic2 - versatile identity manager
# Copyright (C) 2010-2019 Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.template.loader import render_to_string

default_app_config = 'authentic2_idp_oidc.apps.AppConfig'


class Plugin(object):
    def get_before_urls(self):
        from . import urls
        return urls.urlpatterns

    def get_apps(self):
        return [__name__]

    def logout_list(self, request):
        from .utils import get_oidc_sessions
        from . import app_settings

        fragments = []

        oidc_sessions = get_oidc_sessions(request)
        for key, value in oidc_sessions.items():
            if 'frontchannel_logout_uri' not in value:
                continue
            ctx = {
                'url': value['frontchannel_logout_uri'],
                'name': value['name'],
                'iframe_timeout': value.get('frontchannel_timeout') or app_settings.DEFAULT_FRONTCHANNEL_TIMEOUT,
            }
            fragments.append(
                render_to_string(
                    'authentic2_idp_oidc/logout_fragment.html',
                    ctx))
        return fragments
